@@ -38,14 +38,14 @@ hyp_anova <- mtcars_df %>%
 
 test_that("cohesion with type argument", {
   expect_warning(generate(hyp_prop, type = "bootstrap"))
-  expect_warning(generate(hyp_diff_in_props, type = "bootstrap"))
+  expect_silent(generate(hyp_diff_in_props, type = "bootstrap"))
   expect_warning(generate(hyp_chisq_gof, type = "bootstrap"))
-  expect_warning(generate(hyp_chisq_ind, type = "bootstrap"))
+  expect_silent(generate(hyp_chisq_ind, type = "bootstrap"))
   expect_silent(generate(hyp_mean, type = "bootstrap"))
   expect_silent(generate(hyp_median, type = "bootstrap"))
   expect_silent(generate(hyp_sd, type = "bootstrap"))
-  expect_warning(generate(hyp_diff_in_means, type = "bootstrap"))
-  expect_warning(generate(hyp_anova, type = "bootstrap"))
+  expect_silent(generate(hyp_diff_in_means, type = "bootstrap"))
+  expect_silent(generate(hyp_anova, type = "bootstrap"))
 
   expect_silent(generate(hyp_prop, type = "draw"))
   expect_warning(generate(hyp_diff_in_props, type = "draw"))
@@ -190,7 +190,7 @@ test_that("auto `type` works (generate)", {
       generate(reps = 100, type = "bootstrap")
   )
 
-  expect_warning(mtcars_df %>%
+  expect_silent(mtcars_df %>%
       specify(am ~ vs, success = "1") %>% # alt: response = am, explanatory = vs
       hypothesize(null = "independence") %>%
       generate(reps = 100, type = "bootstrap")
@@ -208,18 +208,24 @@ test_that("auto `type` works (generate)", {
       generate(reps = 100, type = "draw")
   )
 
-  expect_warning(mtcars_df %>%
+  expect_silent(mtcars_df %>%
       specify(mpg ~ am) %>% # alt: response = mpg, explanatory = am
       hypothesize(null = "independence") %>%
       generate(reps = 100, type = "bootstrap"))
 
+  expect_silent(
+    mtcars_df %>%
+      specify(mpg ~ am) %>% # alt: response = mpg, explanatory = am
+      generate(reps = 100, type = "bootstrap")
+  )
+
   expect_warning(mtcars_df %>%
       specify(mpg ~ cyl) %>% # alt: response = mpg, explanatory = cyl
       hypothesize(null = "independence") %>%
       generate(reps = 100, type = "draw")
   )
 
-  expect_warning(mtcars_df %>%
+  expect_silent(mtcars_df %>%
       specify(mpg ~ hp) %>% # alt: response = mpg, explanatory = cyl
       hypothesize(null = "independence") %>%
       generate(reps = 100, type = "bootstrap")
@@ -278,7 +284,7 @@ test_that("generate() handles `NULL` value of `type`", {
   )
 })
 
-test_that("generate() handles `x` response in case of 'simulate' (#299)", {
+test_that("generate() handles `x` response", {
   expect_named(
     data.frame(x = factor(rbinom(100, size = 1, prob = .5))) %>%
       specify(response = x, success = "1") %>%
@@ -286,6 +292,14 @@ test_that("generate() handles `x` response in case of 'simulate' (#299)", {
       generate(reps = 100, type = "draw"),
     c("x", "replicate")
   )
+
+  expect_named(
+    data.frame(category = c(rep(c("A", "B"), each = 5)), x = 1:10) %>%
+      specify(explanatory = category, response = x) %>%
+      hypothesize(null = "independence") %>%
+      generate(reps = 5, type = "permute"),
+    c("x", "category", "replicate")
+  )
 })
 
 test_that("generate() can permute with multiple explanatory variables", {
@@ -293,7 +307,7 @@ test_that("generate() can permute with multiple explanatory variables", {
   # are being left alone, then each age + college combination
   # should exist in every replicate
   expect_true(
-    gss %>% 
+    gss %>%
       # add random noise to make the variable truly continuous
       dplyr::mutate(age = age + rnorm(nrow(gss))) %>%
       specify(hours ~ age + college) %>%
@@ -305,42 +319,42 @@ test_that("generate() can permute with multiple explanatory variables", {
       `==`(3) %>%
       all()
   )
-  
-  x <- gss %>% 
+
+  x <- gss %>%
     specify(hours ~ age + college) %>%
     hypothesize(null = "independence") %>%
     generate(reps = 3, type = "permute")
-  
+
   expect_true(inherits(x, "infer"))
   expect_true(inherits(explanatory_variable(x), "tbl_df"))
   expect_true(inherits(explanatory_name(x), "character"))
   expect_true(inherits(explanatory_expr(x), "call"))
-  
+
   expect_equal(explanatory_name(x), c("age", "college"))
   expect_equal(response_name(x), "hours")
-  
+
   expect_equal(nrow(x), 1500)
   expect_equal(ncol(x), 4)
 })
 
 test_that("generate is sensitive to the variables argument", {
   # default argument works appropriately
-  expect_equal({ 
+  expect_equal({
       set.seed(1)
-      
+
       gss[1:10,] %>%
         specify(hours ~ age + college) %>%
         hypothesize(null = "independence") %>%
         generate(reps = 2, type = "permute")
-      }, { 
+      }, {
       set.seed(1)
-      
+
       gss[1:10,] %>%
         specify(hours ~ age + college) %>%
         hypothesize(null = "independence") %>%
         generate(reps = 2, type = "permute", variables = hours)
   })
-  
+
   # permuting changes output
   expect_silent(
     perm_age <- gss[1:10,] %>%
@@ -348,46 +362,46 @@ test_that("generate is sensitive to the variables argument", {
       hypothesize(null = "independence") %>%
       generate(reps = 2, type = "permute", variables = age)
   )
-  
+
   expect_false(all(perm_age$age[1:10] == perm_age$age[11:20]))
   expect_true(all(perm_age$hours[1:10] == perm_age$hours[11:20]))
   expect_true(all(perm_age$college[1:10] == perm_age$college[11:20]))
-  
+
   expect_silent(
     perm_college <- gss[1:10,] %>%
       specify(hours ~ age + college) %>%
       hypothesize(null = "independence") %>%
       generate(reps = 2, type = "permute", variables = college)
   )
-  
+
   expect_true(all(perm_college$age[1:10] == perm_college$age[11:20]))
   expect_true(all(perm_college$hours[1:10] == perm_college$hours[11:20]))
   expect_false(all(perm_college$college[1:10] == perm_college$college[11:20]))
-  
+
   expect_silent(
     perm_college_age <- gss[1:10,] %>%
       specify(hours ~ age + college) %>%
       hypothesize(null = "independence") %>%
       generate(reps = 2, type = "permute", variables = c(college, age))
   )
-  
+
   expect_false(all(perm_college_age$age[1:10] == perm_college_age$age[11:20]))
   expect_true(all(perm_college_age$hours[1:10] == perm_college_age$hours[11:20]))
   expect_false(all(perm_college_age$college[1:10] == perm_college_age$college[11:20]))
-  
+
   # interaction effects are ignored
-  expect_equal({ 
+  expect_equal({
     set.seed(1)
-    
+
     expect_message(
       gss[1:10,] %>%
         specify(hours ~ age + college) %>%
         hypothesize(null = "independence") %>%
         generate(reps = 2, type = "permute", variables = c(hours, age*college))
     )
-  }, { 
+  }, {
     set.seed(1)
-    
+
     gss[1:10,] %>%
       specify(hours ~ age + college) %>%
       hypothesize(null = "independence") %>%
@@ -403,7 +417,7 @@ test_that("variables argument prompts when it ought to", {
       generate(reps = 2, type = "permute", variables = c(howdy)),
     "howdy.*is not in the supplied data."
   )
-  
+
   expect_error(
     gss[1:10,] %>%
       specify(hours ~ age + college) %>%
@@ -411,7 +425,7 @@ test_that("variables argument prompts when it ought to", {
       generate(reps = 2, type = "permute", variables = c(howdy, doo)),
     'columns.*"howdy", "doo".*are not in the supplied data.'
   )
-  
+
   expect_warning(
     gss[1:10,] %>%
       specify(hours ~ NULL) %>%
@@ -419,7 +433,7 @@ test_that("variables argument prompts when it ought to", {
       generate(reps = 2, type = "bootstrap", variables = c(hours)),
     "is only relevant for.*will be ignored."
   )
-  
+
   expect_error(
     gss[1:10,] %>%
       specify(hours ~ age + college) %>%
@@ -427,7 +441,7 @@ test_that("variables argument prompts when it ought to", {
       generate(reps = 2, type = "permute", variables = "hours"),
     'unquoted variable names'
   )
-  
+
   expect_message(
     gss[1:10,] %>%
       specify(hours ~ age + college + age*college) %>%
@@ -435,7 +449,7 @@ test_that("variables argument prompts when it ought to", {
       generate(reps = 2, type = "permute", variables = age*college),
     "supply only data columns"
   )
-  
+
   expect_message(
     gss[1:10,] %>%
       specify(hours ~ age + college + age*college) %>%
@@ -443,28 +457,28 @@ test_that("variables argument prompts when it ought to", {
       generate(reps = 2, type = "permute", variables = c(hours, age*college)),
     "supply only data columns"
   )
-  
+
   expect_silent(
     gss[1:10,] %>%
       specify(hours ~ age + college + age*college) %>%
       hypothesize(null = "independence") %>%
       generate(reps = 2, type = "permute", variables = c(hours))
   )
-  
+
   expect_silent(
     gss[1:10,] %>%
       specify(hours ~ age + college + age*college) %>%
       hypothesize(null = "independence") %>%
       generate(reps = 2, type = "permute")
   )
-  
+
   expect_silent(
     gss[1:10,] %>%
       specify(hours ~ age + college) %>%
       hypothesize(null = "independence") %>%
       generate(reps = 2, type = "permute")
   )
-  
+
   # warn on type != permute but don't raise message re: interaction
   # effects unless otherwise used appropriately
   expect_silent(
@@ -472,8 +486,8 @@ test_that("variables argument prompts when it ought to", {
       gss[1:10,] %>%
         specify(hours ~ age*college) %>%
         generate(
-          reps = 2, 
-          type = "bootstrap", 
+          reps = 2,
+          type = "bootstrap",
           variables = c(hours, age*college)
         )
     )
@@ -489,7 +503,7 @@ test_that("type = 'draw'/'simulate' superseding handled gracefully", {
       generate(type = "simulate"),
     '`"simulate"` generation type.*renamed to `"draw"`.*quiet'
   )
-  
+
   # don't message on type = 'draw'
   expect_silent(
     mtcars_df %>%
@@ -506,7 +520,7 @@ test_that("type = 'draw'/'simulate' superseding handled gracefully", {
       generate(type = "boop"),
     'should be one of "bootstrap", "permute", or "draw"'
   )
-  
+
   # warns with either alias when given unexpected generate type
   expect_error(
     expect_warning(
@@ -517,7 +531,7 @@ test_that("type = 'draw'/'simulate' superseding handled gracefully", {
       'have given `type = "draw"`.*expected to be `"bootstrap"`.*untested'
     )
   )
-  
+
   expect_error(
     expect_warning(
       mtcars_df %>%
@@ -527,11 +541,11 @@ test_that("type = 'draw'/'simulate' superseding handled gracefully", {
       'have given `type = "draw"`.*expected to be `"bootstrap"`.*untested'
     )
   )
-  
+
   expect_equivalent(
     {
       set.seed(1)
-      
+
       expect_message(
         mtcars_df %>%
           specify(response = am, success = "1") %>%
@@ -540,7 +554,7 @@ test_that("type = 'draw'/'simulate' superseding handled gracefully", {
       )
     }, {
       set.seed(1)
-      
+
       mtcars_df %>%
         specify(response = am, success = "1") %>%
         hypothesize(null = "point", p = .5) %>%
@@ -548,3 +562,21 @@ test_that("type = 'draw'/'simulate' superseding handled gracefully", {
     }
   )
 })
+
+test_that("has_p_param handles edge cases", {
+   x <- NA
+
+   set_p_names <- function(x, to) {
+      attr(x, "params") <- rep(NA, length(to))
+      names(attr(x, "params")) <- to
+      x
+   }
+
+   expect_true (has_p_param(set_p_names(x, c("p.boop"))))
+   expect_true (has_p_param(set_p_names(x, c("p.boop", "p.bop"))))
+   expect_false(has_p_param(set_p_names(x, c("p.boop", "pbop"))))
+   expect_false(has_p_param(set_p_names(x, c("p.boop", "bo.p"))))
+   expect_false(has_p_param(set_p_names(x, c("p.boop", "pbop"))))
+   expect_false(has_p_param(set_p_names(x, c(".p.boop"))))
+   expect_false(has_p_param(set_p_names(x, c("beep.boop"))))
+})
